#include "spaceship.h"

// initialization
int main_quit_flag = 0;

// main function
void main(void)
{
	InitGamePad();
// 	SsInit();

	GsInitGraphQuick(SCREEN_W, SCREEN_H);

	act = GsGetActiveBuff();
	GsSetWorkBase(&primitive_buffer[act][0]);

	// draw black color background
	ClearScreen();

	// call initialization function
	InitBGSound();
	InitSprite();

	// init our starfields
	init_Stars(fStars, 100, 240); // foreground
	init_Stars(mStars, 200, 120); // stars in the middle
	init_Stars(bStars, 300,  60); // stars in the back

	// main game loop
	while(main_quit_flag == 0)
	{
		// play background sound
		PlayBGSound();

		// draw background picture
		PrepareSprite(0);
		PrepareSprite(0);

		// background stars
		do_Stars(bStars, 100, 1);

		// stars in the middle
		do_Stars(mStars, 100, 2);

		// call sprite to refresh/animate
		RefreshSpriteFrame(&spaceship_sprite);

		// draw spaceship
		PrepareSprite(&spaceship_sprite);

		// foreground stars
		do_Stars(fStars, 50, 3);

		// draw top bar
		DrawBox(&top_bar, 255, 255, 255, 1, 0, 0, 320, 30);

		// draw bottom bar
		DrawBox(&bottom_bar, 255, 255, 255, 0, 0, 207, 320, 33);

		// draw 0 logo
		PrepareSprite(&spaceship_sprite);

		// print text title
		FntColor (0, 150, 150, 200);
		FntPrint(0, 105, 12, "Space Ship Demo");
		FntColor (0, 20, 60, 80);
		FntPrint(0, 100, 220, "Press L2 to exit");

		// move the spaceship as required
		if((p1_pad.left || p2_pad.left) && spaceship_sprite.sprite.x > 0)
		{
			MoveSprite(&spaceship_sprite, -2, 0);
		}

		if((p1_pad.right || p2_pad.right)  && spaceship_sprite.sprite.x < 272)
		{
			MoveSprite(&spaceship_sprite, +2, 0);
		}

		if((p1_pad.up || p2_pad.up)  && spaceship_sprite.sprite.y > 0)
		{
			MoveSprite(&spaceship_sprite, 0, -2);
		}

		if((p1_pad.down || p2_pad.down)  && spaceship_sprite.sprite.y < 198)
		{
			MoveSprite(&spaceship_sprite, 0, +2);
		}

		// quit if key pressed
		if(p1_pad.l2_clicked)
		{
			main_quit_flag = 1;
		}

		// draw buffer to screen
		UpdateScreen();

		// read game pad
		UpdateGamePad();
	}

	ClearScreen();

	DeinitGamePad();
// 	SsStop();
}

// update the screen
void UpdateScreen(void)
{
	// draw buffer to screen
	WaitVSync();
	GsSwapDispBuff();
	GsDrawOT ((u_long *) &primitive_buffer[act][0]);

	act = GsGetActiveBuff();
	GsSetWorkBase(&primitive_buffer[act][0]);

	// clear screen;
	ClearScreen();
}

// clear the screen
void ClearScreen(void)
{
	GsSortClear (0, 0, 0);
}

// initialize background sound
void InitBGSound(void)
{
// 	InitMod(0, bgmusic);
// 	mod_volume = GetModVol(0);
// 	StartMod(0);
}

// play background sound
void PlayBGSound(void)
{
// 	PollMod(0);
// 	SetModVol(0, mod_volume);
}

// initialize screen sprite
void InitSprite(void)
{

	// setup background left image
	LoadSprite(0, &spaceship_sprite);
	PlaceSprite(&spaceship_sprite, 0, 0);

	// setup background left image
	LoadSprite(0, &spaceship_sprite);
	PlaceSprite(&spaceship_sprite, 160, 0);

	// setup 0 logo image
	LoadSprite(0, &spaceship_sprite);
	PlaceSprite(&spaceship_sprite, 240, 210);

	// setup spaceship image
	LoadAniSprite(0, &spaceship_sprite, 2, 10, 48, 48);
	PlaceSprite(&spaceship_sprite, 24, 80);
	SetSpriteFrame(&spaceship_sprite, 0, 1);
}

// Move and display our "Starfield"
void do_Stars(GsDOT *Stars, int maxStars, u_char speed)
{
	int i;

	// loop to move and display all "stars"
	for(i=0; i<maxStars; i++)
	{
		// move star on x axis (right direction)
		// is star is out of screen, set new x position
		if((Stars[i].x -= speed) < 0)
		{
			Stars[i].x = 480 - rand() % 160;
		}

		// add star into ot
		GsSortDot(&Stars[i]);
	}
}


// Initialize our "Starfield"
void init_Stars(GsDOT *Stars, int maxStars, u_char color)
{
	int i;

	// init randomizer
	rand();

	// loop to init all "stars"
	for(i=0; i<maxStars; i++)
	{
		// set the red, green, blue value of a GsDOT structure
		setDOT_RGB
		(
			&Stars[i], // pointer to GsDOT structure
			color, // red value
			color, // green value
			color // blue value
		);

		// set the x and y position of a GsDOT structure
		setDOT_XY
		(
			&Stars[i],  // pointer to GsDOT structure
			-160+rand()%480, // x position
			rand()%240 // y position
		);
	}
}

// Set Color for a GsDOT
void setDOT_RGB(GsDOT* dot, u_char r, u_char g, u_char b)
{
	dot->r = r;
	dot->g = g;
	dot->b = b;
}


// Set X, Y Position for a GsDOT
void setDOT_XY(GsDOT* dot, short x, short y)
{
	dot->x = x;
	dot->y = y;
}

